@@ -236,6 +236,11 @@ setMethod(
     timezone <- check_timezone(timezone)
     
     con@info$timezone <- timezone
+    
+    # align expiration time to dbConnection timezone
+    if(!is.null(con@info$expiration))
+      attr(con@info$expiration, "tzone") <- timezone
+    
     # integrate with RStudio
     on_connection_opened(con)
     return(con)
