@@ -34,4 +34,7 @@ register_s3_method <- function(pkg, generic, class, fun = NULL) {
   )
 }
 
-readr_check <- function() if (!requireNamespace("readr", quietly = TRUE)) packageStartupMessage("Info: For extra speed please install `readr`.")
\ No newline at end of file
+readr_check <- function() {
+  if (!nzchar(system.file(package = "readr")))
+    packageStartupMessage("Info: For extra speed please install `readr`.")
+}
